import type { ActionGroupSet } from 'api-state-handlers';
import type { RecordRef, FileSet, JsonData } from 'toolkit-data-structures';
import type { AuthInstructions, FlistInstructions, PlistInstructions, SlistInstructions, RemoveInstructions, RetrieveInstructions, StoreInstructions, TaskInstructions, UpdateInstructions } from 'api-state-instructions';
import type { Constructor } from 'toolkit-data-structures';
import type { RecordConfig } from 'toolkit-config';
import type { PlistQuery, SlistQuery, FlistQuery } from 'toolkit-list-structures';
import { StoreHandler, UpdateHandler, RetrieveHandler, FlistHandler, PlistHandler, SlistHandler, RemoveHandler, AuthHandler, TaskHandler } from 'api-state-handlers';
import { AuthImplementation } from 'records-handler-unit';
interface ActionGroup {
    stores: {
        [key: string]: {
            [key: string]: Constructor<StoreHandler, [string]>;
        };
    };
    updates: {
        [key: string]: {
            [key: string]: Constructor<UpdateHandler, [string]>;
        };
    };
    retrievers: {
        [key: string]: {
            [key: string]: Constructor<RetrieveHandler, [string]>;
        };
    };
    flists: {
        [key: string]: {
            [key: string]: Constructor<FlistHandler, [string]>;
        };
    };
    plists: {
        [key: string]: {
            [key: string]: Constructor<PlistHandler, [string]>;
        };
    };
    slists: {
        [key: string]: {
            [key: string]: Constructor<SlistHandler, [string]>;
        };
    };
    removers: {
        [key: string]: {
            [key: string]: Constructor<RemoveHandler, [string]>;
        };
    };
    auths: {
        [key: string]: {
            [key: string]: Constructor<AuthHandler, [string]>;
        };
    };
    tasks: {
        [key: string]: {
            [key: string]: Constructor<TaskHandler, [string]>;
        };
    };
    configs: {
        [key: string]: RecordConfig;
    };
}
declare const getActionGroups: (actionGroups: ActionGroupSet) => ActionGroup;
declare const getStoreInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, payload: JsonData, files: FileSet, recordConfig: RecordConfig) => Promise<StoreInstructions>;
declare const getUpdateInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, payload: JsonData, files: FileSet, recordConfig: RecordConfig) => Promise<UpdateInstructions>;
declare const getRetrieveInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, recordConfig: RecordConfig) => Promise<RetrieveInstructions>;
declare const getFlistInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, flistQuery: FlistQuery, recordConfig: RecordConfig) => Promise<FlistInstructions>;
declare const getPlistInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, plistQuery: PlistQuery, recordConfig: RecordConfig) => Promise<PlistInstructions>;
declare const getSlistInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, slistQuery: SlistQuery, recordConfig: RecordConfig) => Promise<SlistInstructions>;
declare const getRemoveInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, recordConfig: RecordConfig) => Promise<RemoveInstructions>;
declare const getAuthInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, payload: JsonData, files: FileSet, recordConfig: RecordConfig) => Promise<AuthInstructions>;
declare const getTaskInstructions: (authImplementation: AuthImplementation, authorization: string | null, targetRef: RecordRef, payload: JsonData, files: FileSet, recordConfig: RecordConfig) => Promise<TaskInstructions>;
export { getActionGroups, getStoreInstructions, getUpdateInstructions, getRetrieveInstructions, getFlistInstructions, getPlistInstructions, getSlistInstructions, getRemoveInstructions, getAuthInstructions, getTaskInstructions, };
