"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTaskInstructions = exports.getAuthInstructions = exports.getRemoveInstructions = exports.getSlistInstructions = exports.getPlistInstructions = exports.getFlistInstructions = exports.getRetrieveInstructions = exports.getUpdateInstructions = exports.getStoreInstructions = exports.getActionGroups = void 0;
const records_query_handler_1 = require("records-query-handler");
const records_handler_unit_1 = require("records-handler-unit");
const toolkit_contracts_1 = require("toolkit-contracts");
//
const camelToKebab = (str) => {
    str = str.charAt(0).toLowerCase() + str.substr(1);
    return str.replace(/([a-z0-9]|(?=[A-Z]))([A-Z])/g, '$1-$2').toLowerCase();
};
//
const getActionGroups = (actionGroups) => {
    const stores = {};
    const updates = {};
    const retrievers = {};
    const flists = {};
    const plists = {};
    const slists = {};
    const removers = {};
    const auths = {};
    const tasks = {};
    const configs = {};
    for (let [repository, actionGroup] of Object.entries(actionGroups)) {
        // stores
        if (!stores[repository]) {
            stores[repository] = {};
        }
        for (let creator of actionGroup.stores) {
            stores[repository][camelToKebab(creator.prototype.constructor.name)] = creator;
        }
        // updates
        if (!updates[repository]) {
            updates[repository] = {};
        }
        for (let updater of actionGroup.updates) {
            updates[repository][camelToKebab(updater.prototype.constructor.name)] = updater;
        }
        // retrievers
        if (!retrievers[repository]) {
            retrievers[repository] = {};
        }
        for (let retriever of actionGroup.retrievers) {
            retrievers[repository][camelToKebab(retriever.prototype.constructor.name)] = retriever;
        }
        // flists
        if (!flists[repository]) {
            flists[repository] = {};
        }
        for (let flist of actionGroup.flists) {
            flists[repository][camelToKebab(flist.prototype.constructor.name)] = flist;
        }
        // plists
        if (!plists[repository]) {
            plists[repository] = {};
        }
        for (let plist of actionGroup.plists) {
            plists[repository][camelToKebab(plist.prototype.constructor.name)] = plist;
        }
        // slists
        if (!slists[repository]) {
            slists[repository] = {};
        }
        for (let slist of actionGroup.slists) {
            slists[repository][camelToKebab(slist.prototype.constructor.name)] = slist;
        }
        // removers
        if (!removers[repository]) {
            removers[repository] = {};
        }
        for (let remover of actionGroup.removers) {
            removers[repository][camelToKebab(remover.prototype.constructor.name)] = remover;
        }
        // auths
        if (!auths[repository]) {
            auths[repository] = {}; //
        }
        for (let auth of actionGroup.auths) {
            auths[repository][camelToKebab(auth.prototype.constructor.name)] = auth;
        }
        // tasks
        if (!tasks[repository]) {
            tasks[repository] = {};
        }
        for (let task of actionGroup.tasks) {
            tasks[repository][camelToKebab(task.prototype.constructor.name)] = task;
        }
        // config
        configs[repository] = actionGroup.config;
    }
    return {
        stores,
        updates,
        retrievers,
        flists,
        plists,
        slists,
        removers,
        auths,
        tasks,
        configs,
    };
};
exports.getActionGroups = getActionGroups;
//
const getStoreInstructions = (authImplementation, authorization, targetRef, payload, files, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        filter: null,
        fill: null,
        authRecord,
        files,
        target: null,
        targetRef,
        payload,
        storeResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getStoreInstructions = getStoreInstructions;
const getUpdateInstructions = (authImplementation, authorization, targetRef, payload, files, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        filter: null,
        fill: null,
        authRecord,
        files,
        target: null,
        targetRef,
        payload,
        updateResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getUpdateInstructions = getUpdateInstructions;
const getRetrieveInstructions = (authImplementation, authorization, targetRef, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        authRecord,
        target: null,
        targetRef,
        retrieveResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getRetrieveInstructions = getRetrieveInstructions;
const getFlistInstructions = (authImplementation, authorization, targetRef, flistQuery, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const query = records_query_handler_1.getQueryHandler();
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    flistQuery.builder = query(flistQuery.repository);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        authRecord,
        target: null,
        targetRef,
        flistQuery,
        listResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getFlistInstructions = getFlistInstructions;
const getPlistInstructions = (authImplementation, authorization, targetRef, plistQuery, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const query = records_query_handler_1.getQueryHandler();
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    plistQuery.builder = query(plistQuery.repository);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        authRecord,
        target: null,
        targetRef,
        plistQuery,
        listResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getPlistInstructions = getPlistInstructions;
const getSlistInstructions = (authImplementation, authorization, targetRef, slistQuery, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const query = records_query_handler_1.getQueryHandler();
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    slistQuery.builder = query(slistQuery.repository);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        authRecord,
        target: null,
        targetRef,
        slistQuery,
        listResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getSlistInstructions = getSlistInstructions;
const getRemoveInstructions = (authImplementation, authorization, targetRef, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        authRecord,
        target: null,
        targetRef,
        removeResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getRemoveInstructions = getRemoveInstructions;
const getAuthInstructions = (authImplementation, authorization, targetRef, payload, files, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    return {
        recordConfig,
        recordHandler,
        filter: null,
        fill: null,
        authRecord,
        target: null,
        targetRef,
        payload,
        files,
        authResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getAuthInstructions = getAuthInstructions;
const getTaskInstructions = (authImplementation, authorization, targetRef, payload, files, recordConfig) => __awaiter(void 0, void 0, void 0, function* () {
    const recordHandler = new records_handler_unit_1.RecordHandler(authImplementation);
    const authRecord = yield recordHandler.auth().token(authorization);
    return {
        recordConfig,
        recordHandler,
        requiredAuthRecords: null,
        filter: null,
        fill: null,
        authRecord,
        target: null,
        targetRef,
        payload,
        files,
        taskResult: null,
        result: null,
        resultMsg: null,
        resultData: {},
        success: false,
        sideEffect: null,
        getFlags: toolkit_contracts_1.GetFlagsContract,
    };
});
exports.getTaskInstructions = getTaskInstructions;
